# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: apis/inference/v1/infer.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from apis.inference.v1 import image_pb2 as apis_dot_inference_dot_v1_dot_image__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x61pis/inference/v1/infer.proto\x12\x0cinference.v1\x1a\x1d\x61pis/inference/v1/image.protoBo\n\x10\x63om.inference.v1B\nInferProtoP\x01\xa2\x02\x03IXX\xaa\x02\x0cInference.V1\xca\x02\x0cInference\\V1\xe2\x02\x18Inference\\V1\\GPBMetadata\xea\x02\rInference::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'apis.inference.v1.infer_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\020com.inference.v1B\nInferProtoP\001\242\002\003IXX\252\002\014Inference.V1\312\002\014Inference\\V1\342\002\030Inference\\V1\\GPBMetadata\352\002\rInference::V1'
# @@protoc_insertion_point(module_scope)
