# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: apis/inference/v1/image.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from apis.inference.v1 import open_inference_pb2 as apis_dot_inference_dot_v1_dot_open__inference__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x61pis/inference/v1/image.proto\x12\x0cinference.v1\x1a&apis/inference/v1/open_inference.proto\"\xa6\x04\n\x11InferImageRequest\x12\x1d\n\nmodel_name\x18\x01 \x01(\tR\tmodelName\x12#\n\rmodel_version\x18\x02 \x01(\tR\x0cmodelVersion\x12\x0e\n\x02id\x18\x03 \x01(\tR\x02id\x12\x14\n\x05image\x18\x04 \x01(\x0cR\x05image\x12\x1b\n\timage_url\x18\x05 \x01(\tR\x08imageUrl\x12H\n\x06option\x18\x06 \x01(\x0b\x32\x30.inference.v1.InferImageRequest.InferImageOptionR\x06option\x1a\x9e\x01\n\nImageScale\x12!\n\x0cimage_height\x18\x01 \x01(\x05R\x0bimageHeight\x12\x1f\n\x0bimage_width\x18\x02 \x01(\x05R\nimageWidth\x12$\n\x0emax_image_size\x18\x03 \x01(\x05R\x0cmaxImageSize\x12&\n\x0fimage_size_unit\x18\x04 \x01(\x05R\rimageSizeUnit\x1a\x9e\x01\n\x10InferImageOption\x12@\n\x05scale\x18\x01 \x01(\x0b\x32*.inference.v1.InferImageRequest.ImageScaleR\x05scale\x12\"\n\ruse_cv2_color\x18\x02 \x01(\x08R\x0buseCv2Color\x12$\n\rnormalization\x18\x03 \x01(\x08R\rnormalization\"\xb7\x01\n\x12InferImageResponse\x12G\n\x0emodel_response\x18\x01 \x01(\x0b\x32 .inference.v1.ModelInferResponseR\rmodelResponse\x12,\n\x12input_image_height\x18\x02 \x01(\x05R\x10inputImageHeight\x12*\n\x11input_image_width\x18\x03 \x01(\x05R\x0finputImageWidth2j\n\x15ImageInferenceService\x12Q\n\nInferImage\x12\x1f.inference.v1.InferImageRequest\x1a .inference.v1.InferImageResponse\"\x00\x42o\n\x10\x63om.inference.v1B\nImageProtoP\x01\xa2\x02\x03IXX\xaa\x02\x0cInference.V1\xca\x02\x0cInference\\V1\xe2\x02\x18Inference\\V1\\GPBMetadata\xea\x02\rInference::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'apis.inference.v1.image_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\020com.inference.v1B\nImageProtoP\001\242\002\003IXX\252\002\014Inference.V1\312\002\014Inference\\V1\342\002\030Inference\\V1\\GPBMetadata\352\002\rInference::V1'
  _globals['_INFERIMAGEREQUEST']._serialized_start=88
  _globals['_INFERIMAGEREQUEST']._serialized_end=638
  _globals['_INFERIMAGEREQUEST_IMAGESCALE']._serialized_start=319
  _globals['_INFERIMAGEREQUEST_IMAGESCALE']._serialized_end=477
  _globals['_INFERIMAGEREQUEST_INFERIMAGEOPTION']._serialized_start=480
  _globals['_INFERIMAGEREQUEST_INFERIMAGEOPTION']._serialized_end=638
  _globals['_INFERIMAGERESPONSE']._serialized_start=641
  _globals['_INFERIMAGERESPONSE']._serialized_end=824
  _globals['_IMAGEINFERENCESERVICE']._serialized_start=826
  _globals['_IMAGEINFERENCESERVICE']._serialized_end=932
# @@protoc_insertion_point(module_scope)
