# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: apis/inference/v1/open_inference.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&apis/inference/v1/open_inference.proto\x12\x0cinference.v1\"\xf1\x05\n\x12ModelInferResponse\x12\x1d\n\nmodel_name\x18\x01 \x01(\tR\tmodelName\x12#\n\rmodel_version\x18\x02 \x01(\tR\x0cmodelVersion\x12\x0e\n\x02id\x18\x03 \x01(\tR\x02id\x12P\n\nparameters\x18\x04 \x03(\x0b\x32\x30.inference.v1.ModelInferResponse.ParametersEntryR\nparameters\x12L\n\x07outputs\x18\x05 \x03(\x0b\x32\x32.inference.v1.ModelInferResponse.InferOutputTensorR\x07outputs\x12.\n\x13raw_output_contents\x18\x06 \x03(\x0cR\x11rawOutputContents\x1a\xd9\x02\n\x11InferOutputTensor\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x1a\n\x08\x64\x61tatype\x18\x02 \x01(\tR\x08\x64\x61tatype\x12\x14\n\x05shape\x18\x03 \x03(\x03R\x05shape\x12\x62\n\nparameters\x18\x04 \x03(\x0b\x32\x42.inference.v1.ModelInferResponse.InferOutputTensor.ParametersEntryR\nparameters\x12=\n\x08\x63ontents\x18\x05 \x01(\x0b\x32!.inference.v1.InferTensorContentsR\x08\x63ontents\x1a[\n\x0fParametersEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x32\n\x05value\x18\x02 \x01(\x0b\x32\x1c.inference.v1.InferParameterR\x05value:\x02\x38\x01\x1a[\n\x0fParametersEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x32\n\x05value\x18\x02 \x01(\x0b\x32\x1c.inference.v1.InferParameterR\x05value:\x02\x38\x01\"\xd7\x01\n\x0eInferParameter\x12\x1f\n\nbool_param\x18\x01 \x01(\x08H\x00R\tboolParam\x12!\n\x0bint64_param\x18\x02 \x01(\x03H\x00R\nint64Param\x12#\n\x0cstring_param\x18\x03 \x01(\tH\x00R\x0bstringParam\x12#\n\x0c\x64ouble_param\x18\x04 \x01(\x01H\x00R\x0b\x64oubleParam\x12#\n\x0cuint64_param\x18\x05 \x01(\x04H\x00R\x0buint64ParamB\x12\n\x10parameter_choice\"\xc3\x02\n\x13InferTensorContents\x12#\n\rbool_contents\x18\x01 \x03(\x08R\x0c\x62oolContents\x12!\n\x0cint_contents\x18\x02 \x03(\x05R\x0bintContents\x12%\n\x0eint64_contents\x18\x03 \x03(\x03R\rint64Contents\x12#\n\ruint_contents\x18\x04 \x03(\rR\x0cuintContents\x12\'\n\x0fuint64_contents\x18\x05 \x03(\x04R\x0euint64Contents\x12#\n\rfp32_contents\x18\x06 \x03(\x02R\x0c\x66p32Contents\x12#\n\rfp64_contents\x18\x07 \x03(\x01R\x0c\x66p64Contents\x12%\n\x0e\x62ytes_contents\x18\x08 \x03(\x0cR\rbytesContentsBw\n\x10\x63om.inference.v1B\x12OpenInferenceProtoP\x01\xa2\x02\x03IXX\xaa\x02\x0cInference.V1\xca\x02\x0cInference\\V1\xe2\x02\x18Inference\\V1\\GPBMetadata\xea\x02\rInference::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'apis.inference.v1.open_inference_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\020com.inference.v1B\022OpenInferenceProtoP\001\242\002\003IXX\252\002\014Inference.V1\312\002\014Inference\\V1\342\002\030Inference\\V1\\GPBMetadata\352\002\rInference::V1'
  _globals['_MODELINFERRESPONSE_INFEROUTPUTTENSOR_PARAMETERSENTRY']._options = None
  _globals['_MODELINFERRESPONSE_INFEROUTPUTTENSOR_PARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_MODELINFERRESPONSE_PARAMETERSENTRY']._options = None
  _globals['_MODELINFERRESPONSE_PARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_MODELINFERRESPONSE']._serialized_start=57
  _globals['_MODELINFERRESPONSE']._serialized_end=810
  _globals['_MODELINFERRESPONSE_INFEROUTPUTTENSOR']._serialized_start=372
  _globals['_MODELINFERRESPONSE_INFEROUTPUTTENSOR']._serialized_end=717
  _globals['_MODELINFERRESPONSE_INFEROUTPUTTENSOR_PARAMETERSENTRY']._serialized_start=626
  _globals['_MODELINFERRESPONSE_INFEROUTPUTTENSOR_PARAMETERSENTRY']._serialized_end=717
  _globals['_MODELINFERRESPONSE_PARAMETERSENTRY']._serialized_start=626
  _globals['_MODELINFERRESPONSE_PARAMETERSENTRY']._serialized_end=717
  _globals['_INFERPARAMETER']._serialized_start=813
  _globals['_INFERPARAMETER']._serialized_end=1028
  _globals['_INFERTENSORCONTENTS']._serialized_start=1031
  _globals['_INFERTENSORCONTENTS']._serialized_end=1354
# @@protoc_insertion_point(module_scope)
